@@ -92,11 +92,12 @@ def classy_learner(
             counter = dict(Counter(annotations))
             if all([v >= min_n_samples for v in counter.values()]):
                 # format data for classy-classification
-                data = dict.fromkeys(counter.keys(), [])
+                data = {}
+                for key in counter.keys():
+                    data[key] = []
                 for key, value in zip(annotations, texts):
                     if len(data[key]) <= max_n_samples:
                         data[key].append(value)
-
                 # re-initialize classifier if there is new data
                 if ctx.query_params["data"] == data:
                     classy_classifier = ctx.query_params["classy_classifier"]
@@ -134,6 +135,7 @@ def classy_learner(
                     updated_records = []
                     texts = [rec.text for rec in records_new]
                     predictions = classy_classifier.pipe(texts)
+
                     for rec, pred in zip(records_new, predictions):
                         max_new_pred = pred[max(pred, key=pred.get)]
                         max_old_pred = 0
